@@ -41,13 +41,18 @@ def downloadfile(url, filename):
     with requests.get(url, stream=True) as r:
         filesize = r.headers["Content-Length"]
         chunk_size = 1024
-        print("Downloading " + url+" ("+format(float(filesize)/1000/1000, '.2f')+" MB)")
-        with tqdm(total=float(filesize),unit='B',unit_scale=True,desc=url.split('/')[-1]) as pbar:
-            with open(filename, "wb") as fw:
-                for chunk in r.iter_content(chunk_size):
-                    if chunk:
-                        fw.write(chunk)
-                        pbar.update(chunk_size)
+        print("Downloading " + url+" ("+format(float(filesize)/1024/1024, '.2f')+" MB)")
+        try:
+            with tqdm(total=float(filesize),unit='B',unit_scale=True,unit_divisor=1024,miniters=1,leave=False,file=sys.stdout) as pbar:
+                with open(filename, "wb") as fw:
+                    for chunk in r.iter_content(chunk_size):
+                        if chunk:
+                            fw.write(chunk)
+                            pbar.update(chunk_size)
+        except KeyboardInterrupt:
+            pbar.close()
+            raise
+        pbar.close()
 
 def get_latest_release_url():
     git_version=""
